#
# spec file for package inspektor-gadget
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           inspektor-gadget
Version:        0.30.0
Release:        1.1
Summary:        A eBPF tool and systems inspection framework
License:        Apache-2.0
URL:            https://github.com/inspektor-gadget/inspektor-gadget
Source:         inspektor-gadget-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go1.22
# /usr/bin/ig conflicts with igrep
Conflicts:      igrep

%description
The eBPF tool and systems inspection framework for Kubernetes, containers and
Linux hosts

Inspektor Gadget is a collection of tools (or gadgets) to debug and inspect
Kubernetes resources and applications. It manages the packaging, deployment and
execution of eBPF programs in a Kubernetes cluster, including many based on BCC
tools, as well as some developed specifically for use in Inspektor Gadget. It
automatically maps low-level kernel primitives to high-level Kubernetes
resources, making it easier and quicker to find the relevant information.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -a 1 -p 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/inspektor-gadget/inspektor-gadget/internal/version.version=%{version} \
   -X main.gadgetimage=ghcr.io/inspektor-gadget/inspektor-gadget:latest" \
   -tags withoutebpf \
   -o bin/kubectl-gadget \
   github.com/inspektor-gadget/inspektor-gadget/cmd/kubectl-gadget

go build \
   -mod=vendor \
   -buildmode=pie \
   -tags withoutebpf \
   -ldflags=" \
   -X github.com/inspektor-gadget/inspektor-gadget/internal/version.version=%{version} \
   -X main.gadgetimage=ghcr.io/inspektor-gadget/inspektor-gadget:latest" \
   -o bin/gadgetctl \
   github.com/inspektor-gadget/inspektor-gadget/cmd/gadgetctl

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/inspektor-gadget/inspektor-gadget/internal/version.version=%{version} \
   -X github.com/inspektor-gadget/inspektor-gadget/cmd/common/image.builderImage=ghcr.io/inspektor-gadget/ebpf-builder:latest" \
   -tags netgo \
   -o bin/ig \
   github.com/inspektor-gadget/inspektor-gadget/cmd/ig

%install
# Install the binary.
install -D -m 0755 bin/kubectl-gadget %{buildroot}/%{_bindir}/kubectl-gadget
install -D -m 0755 bin/gadgetctl %{buildroot}/%{_bindir}/gadgetctl
install -D -m 0755 bin/gadgetctl %{buildroot}/%{_bindir}/ig

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/gadgetctl completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/gadgetctl
%{buildroot}/%{_bindir}/kubectl-gadget completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/kubectl-gadget

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/gadgetctl completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/gadgetctl.fish
%{buildroot}/%{_bindir}/kubectl-gadget completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/kubectl-gadget.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/gadgetctl completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_gadgetctl
%{buildroot}/%{_bindir}/kubectl-gadget completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_kubectl-gadget

%files
%doc README.md
%license LICENSE
%{_bindir}/gadgetctl
%{_bindir}/ig
%{_bindir}/kubectl-gadget

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/gadgetctl
%{_datarootdir}/bash-completion/completions/kubectl-gadget

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/gadgetctl.fish
%{_datarootdir}/fish/vendor_completions.d/kubectl-gadget.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_gadgetctl
%{_datarootdir}/zsh_completion.d/_kubectl-gadget

%changelog
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.0:
  * ci: Set DOCKER_BUILD_NO_SUMMARY.
  * gadgets/trace_capabilities: Add special check for exec-family
    syscalls
  * gadgets: Add trace_capabilities
  * gadgets/trace_tcpdrop: Add kernel stack field
  * pkg/operators/ebpf: Support kernel stack map
  * pkg/oci: Add new options to restrain execution by digest.
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * gadgets: update README.md
  * gadgets/Makefile: add readme target
  * gadgets/trace_exec: Add tests
  * testing: Add helper to sleep
  * treewide: Remove unneeded systemd workaround.
  * ci: Use eastus2 for AKS
  * go: bump github.com/moby/moby
  * go: bump github.com/docker/cli
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * test/images: Test that export command is deterministic
  * build: Allow reproducible builds
  * kubemanager: Check ParamAllNamespaces in PreStart too
  * datasource: Return error on New()
  * go: bump github.com/moby/moby
  * go: bump github.com/docker/cli
  * ci: Remove ARO from release needs.
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * gadgets/snapshot_process: Port test to use new testing
    framework
  * pkg/testing/match: Add unittests
  * testing: Consolidate match logic in pkg/testing/match
  * CI: Use multinode cluster for testing gadgets on kubernetes
  * trace_mount: Add call column and flag decoding
  * docs: Remove mouting /run for ig.
  * pkg/container-utils: Preprend HOST_ROOT to
    /run/cri-dockerd.sock.
  * cmd/ig: Preprend host.HostRoot to runtime socket path.
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * docs: Add instruction to verify ebpf-builder image.
  * ci: Verify eBPF builder image before building gadgets.
  * Revert "container-collection: add process metadata enricher"
  * gadgets/trace_exec: Update metadata.
  * ci: bump docker/build-push-action from 5 to 6
  * ci: bump aquasecurity/trivy-action from 0.22.0 to 0.23.0
  * add sort operator import to ig and gadgettracermanager binaries
  * pkg/datasource: add @flyth as code owner
  * pkg/datasource: improve subscription handling
  * Fix codeowners
  * trace_tcp{drop,retrans}: Use bitfields for flags
  * ebpf/formatters: Support formatting bitfields
  * trace_open: Add missing fields
  * gadgets/test: Run tests even if wasm module exists
  * ig/build: Always pull builder-image if latest tag is used
  * tests: Disable TestTraceNetwork on cri-o
  * gadgets/trace_sni: Port test to use new testing framework
  * pkg/operators/sort: add unit tests
  * add sort operator
  * pkg/datasource: add Swap() method to DataArray
  * gadgets/ports: Convert to host endianess inside the gadget
  * go: bump github.com/containers/image/v5 from 5.31.0 to 5.31.1
  * go: bump github.com/tetratelabs/wazero from 1.7.1 to 1.7.3
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * gadgets/trace_exec: Add wasm module to handle args field
  * docs: Add guide to use wasm from a gadget
  * docs/reference: Add wasm reference docs
  * wasm: Add test to check consts are in sync
  * operators/wasm: Add tests
  * operators: Add wasm operator
  * image/build: Use correct Inspektor Gadget code in in-tree
    gadgets
  * gadgets: Port trace_tcp_test to gadgets
  * pkg/container-hook: Check container PID bound before converting
    it.
  * ci: bump actions/{download,upload}-artifact from 3 to 4
  * formatters: Avoid changing name of the field
  * operators/ebpf: Rename converters to formatters
  * ci: Use westeurope for AKS.
  * container-hook: delete old entries and marks after timeout
  * container-hook: use a single fanotify to watch pid files
  * integration/kubectl-gadget: Add an option to skip image
    verification
  * gadgets/test: Add an option skip image verification
  * ci: Skip signing ig-k8s image/gadget images on fork
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * go: bump github.com/miekg/dns from 1.1.59 to 1.1.61 in
    /tools/dnstester
  * execsnoop: add parent upper layer
  * gadgets/signal: Add test using the new framework.
  * integration/Command: Enhance error messages for kill
  * pkg/oci: Remove undeeded authOpts for getSigningInformation().
  * container-collection: add process metadata enricher
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * gadgets/trace_mount: Implement test using new framework
  * tests: Remove duplicated test
  * testing/containers: Add support for privileged mode
  * gadgets/trace_open: Improve tests
  * gadgets/trace_exec: drop uid filter on sys_exit_execve
  * pkg/gadgets/trace_exec: drop uid filter on sys_exit_execve
  * pkg/gadgets/capabilities: Fix pid field
  * container-hook: add new test
  * pkg/gadgets/capabilities: fix pid and tgid fields
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * ci: Use --format to retrieve image digest instead of grep and
    awk.
  * go: bump github.com/spf13/cobra from 1.8.0 to 1.8.1
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * go: bump github.com/docker/docker
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * ci: Sign helper images.
  * go: bump github.com/moby/moby
  * ci: Sign ig container image.
  * ci: Add action to sign container image.
  * go: bump the k8s group with 8 updates
  * uprobetracer: use secureopen to avoid TOCTOU issues
  * New pkg: secureopen: open files in containers
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * go: bump google.golang.org/protobuf from 1.34.1 to 1.34.2
  * Align k8s json and columns name
  * trace exec: extract fixup for execve as a common header
  * fields: Mark fields hidden based on attributes
  * ci: bump aquasecurity/trivy-action from 0.21.0 to 0.22.0
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * go: bump sigs.k8s.io/controller-runtime from 0.18.3 to 0.18.4
  * go: bump github.com/docker/{cli,docker} and
    github.com/moby/moby
  * go: bump github.com/containerd/containerd from 1.7.17 to 1.7.18
  * go: bump the golang-x group with 3 updates
  * go: bump github.com/containers/common from 0.59.0 to 0.59.1
  * Updating trace_open test to support testing in k8s and adding
    ci job for testing with k8s
  * adding helper functions for testing with k8s
  * gadgets/trace_exec: extract fixup for execve as a common header
  * go: bump github.com/spf13/viper from 1.18.2 to 1.19.0
  * go: bump github.com/mdlayher/socket from 0.4.1 to 0.5.1 in
    /examples
  * Artifact Hub: Update gadgets version to v0.29.0
  * container-collection: Don't rely on k8s.io/kubernetes/pkg/...
  * go: bump github.com/aws/aws-sdk-go in /tools/eks-cleanup
  * implementing container factory interface for k8s
  * updating field names: pod and container
* Mon Jun  3 2024 opensuse_buildservice@ojkastl.de
- update to version 0.29.0:
  * Welcome to the v0.29.0 release of Inspektor Gadget. The most
    relevant changes for this version are:
  - API: Support running gadgets from files and memory by
    @mauriciovasquezbernal in #2853
  - gadgets: Add trace_lsm by @i-Pear in #2827
  - gadgets: Add trace_ssl by @i-Pear in #2745
  - add filter operator by @flyth in #2805
  * General Improvements
  - Improve "CStrings" handling by @mauriciovasquezbernal in
    [#2797]
  - UserGroupCache: Move OnceValue to global scope by @burak-ok
    in #2809
  - kubernetes: cgroupfs: mount read-only by @alban in #2685
  - datasources: Add Bool accessors by @mauriciovasquezbernal in
    [#2796]
  - gadgets/trace_malloc: support more memory operations by
    @i-Pear in #2748
  - datasources: Add missing setters, allocate memory and add
    tests by @mauriciovasquezbernal in #2823
  - trace_dns: convert domain to dot notation (without wasm) by
    @alban in #2845
  - pkg/datasource: remove dependency on pkg/gadgets by @flyth in
    [#2850]
  - pkg/operators/ebpf: Avoid adding netns field to snapshot
    process by @blanquicet in #2838
  - snapshotters: Support sending and JSON-printing output as an
    array by @blanquicet in #2709
  - profile/block-io: use core type matches relocations by @alban
    in #2542
  - Add support for more iterators: task_file, ksym by @alban in
    [#2839]
  - minikube: Upgrade to v1.33.1 by @mqasimsarfraz in #2841
  - datasource: Allow setting smaller static strings by
    @mauriciovasquezbernal in #2832
  - sockets-map.h: remove most defines from socket enricher
    header by @alban in #2846
  - local/kube manager operators: Print warning for multiple
    net/mnt ns fields by @blanquicet in #2877
  - Revert "gadgets/trace_dns: add empty wasm module" by
    @mauriciovasquezbernal in #2886
  - cmd: Add JSON output to image list command. by @eiffel-fl in
    [#2885]
  - cmd/image/build: Add progress bar when pulling builder image
    by @mauriciovasquezbernal in #2888
  - charts: Set container filesystem as read only. by @eiffel-fl
    in #2442
  - pkg/{runcfanotify, container-hook}: Refactor code to use
    notify package. by @eiffel-fl in #2766
  - clean up operator initialization code by @flyth in #2901
  - Auto detect container runtime socket path by @dorser in #2794
  - Updates to dependabot by @mauriciovasquezbernal in #2915
  - pkg/operators/formatters: Add syscall formatter by @i-Pear in
    [#2913]
  - dependabot: Group gomod updates by dependency by
    @mauriciovasquezbernal in #2916
  - dependabot: Disable updating indirect dependencies by
    @mauriciovasquezbernal in #2955
  * Bug Fixes
  - oci-handler: Fix typo in error message by @mqasimsarfraz in
    [#2806]
  - kubectl-gadget: Multiple fixes around skipInfo logic by
    @mauriciovasquezbernal in #2774
  - trace/network: Close Operators after closing the tracer by
    @burak-ok in #2814
  - container-hook: fix sys_exit_execve from thread by @alban in
    [#2804]
  - oci: Fail is start image operator fails by
    @mauriciovasquezbernal in #2828
  - trace exec builtin gadget: fix memory usage by @alban in
    [#2840]
  - pkg/operators/simple: fix onStop() callback being called if
    only onStart is set by @flyth in #2851
  - version: Fix server version for ig-k8s by @mqasimsarfraz in
    [#2852]
  - trace_dns: fix padding by @alban in #2860
  - pkg/gadgets: Update comment about mntns_filter.h location by
    @blanquicet in #2866
  - localmanager: Avoid crashing if container collection isn't
    available by @mauriciovasquezbernal in #2874
  - pkg/operators: Fix tracing host events for mount namespace ID
    attache… by @eiffel-fl in #2879
  - Add runc symlink for rancher rke2 by @matthyx in #2764
  - Remove usage of go workspaces by @mauriciovasquezbernal in
    [#2914]
  - oci: Return error if op.Prepare() fails by
    @mauriciovasquezbernal in #2947
  * Documentation Improvements
  - Artifact Hub: Update gadgets version to v0.28.0 by
    @github-actions in #2808
  - Artifact Hub: Update gadgets version to v0.28.1 by
    @github-actions in #2861
  - Implement image-based gadgets examples by
    @mauriciovasquezbernal in #2753
  - docs: Add installation steps for helm charts by
    @mqasimsarfraz in #2878
  - docs/hello-world-gadget: Add missing --verify-image=false by
    @mauriciovasquezbernal in #2887
  - docs: Add documentation on how to sign image-based gadgets.
    by @eiffel-fl in #2894
  - docs: Use relative link to point to verification
    documentation. by @eiffel-fl in #2895
  - docs: Add initial wasm design doc by @mauriciovasquezbernal
    in #2896
  * Testing and Continue Integration
  - ci: Do not run cloud-cleanup on fork by @mqasimsarfraz in
    [#2807]
  - ci: Shifting deploy and undeploy logic for IG to actions by
    @pawarpranav83 in #2833
  - tests: Add tests for image export and import by
    @mauriciovasquezbernal in #2906
* Mon Jun  3 2024 opensuse_buildservice@ojkastl.de
- update to version 0.28.1:
  This is a Bugfix release which includes the following fixes:
  * container-hook: fix sys_exit_execve from thread by @alban in
    [#2804]
  * trace exec builtin gadget: fix memory usage by @alban in #2840
  * version: Fix server version for ig-k8s by @mqasimsarfraz in
    [#2852]
* Mon Jun  3 2024 opensuse_buildservice@ojkastl.de
- update to version 0.28.0:
  Welcome to the v0.28.0 release of Inspektor Gadget. The most
  relevant changes for this version are:
  * pkg/uprobetracer: add support for USDT tracepoints by @i-Pear
    in #2655
  * cmd: Verifying container image if policy controller is present.
    by @eiffel-fl in #2703
  * operators/ebpf: Support associate programs (iterators) to
    snapshotters by @blanquicet in #2637
  * Bump Go version to 1.22.0 by @burak-ok in #2744
  * Remove bpftrace by @eiffel-fl in #2757
  General Improvements
  * gadget-context: Don't add op instance's params if op is not
    requested by @blanquicet in #2667
  * pkg/uprobetracer: use kfilefields to identify inodes by @i-Pear
    in #2669
  * artifacthub-pkg.yml: update gadget versions to new release by
    @alban in #2679
  * re-add support for jsonpretty + yaml to image based gadgets by
    @flyth in #2652
  * trace/open: Compute error and file descriptor fields on eBPF
    code by @blanquicet in #2687
  * rename methods/structs/interfaces from Gadget... to
    BuiltInGadget... by @flyth in #2559
  * pkg/datasource: Don't use sync.Pool for data by @blanquicet in
    [#2708]
  * Cleanup custom-columns CLI flag by @shivaabhishek07 in #2465
  * cmd: Add --seccomp-profile to specify seccomp profile to apply
    to Inspektor Gadget by @eiffel-fl in #2710
  * treewide: remove run gadget by @flyth in #2673
  * add version skew warning by @mauriciovasquezbernal in #2718
  * run: Remove dead code by @mauriciovasquezbernal in #2740
  * cmd: Do not truncate output when listing image-based gadgets.
    by @eiffel-fl in #2743
  * tests.mk: Update kube-apiserver to 1.30.0 by @burak-ok in #2750
  * oci: Remove dead code by @mauriciovasquezbernal in #2754
  * Sign image based gadgets by @eiffel-fl in #2678
  * image/build: Implement option to keep built file by
    @mauriciovasquezbernal in #2738
  * pkg/uprobetracer: support LSM trace points by @i-Pear in #2747
  * trace/{dns,sni}: Split NewTracer() logic by @amirmalka in #2768
  * Verify image based gadget by @eiffel-fl in #2707
  * Add signal formatter by @mauriciovasquezbernal in #2630
  * gadget-service: Improve address validation by
    @mauriciovasquezbernal in #2780
  * cmd: Implement image import and export commands by
    @mauriciovasquezbernal in #2779
  * columns/filter: Add support for time.Duration by @mqasimsarfraz
    in #2791
  * trace exec: Add user and group field by @burak-ok in #2751
  * image-based gadgets: Implement btfgen support by
    @mauriciovasquezbernal in #2598
  Bug Fixes
  * charts: Add '/host/var' to volumeMounts by @mqasimsarfraz in
    [#2664]
  * image based gadgets: fix hostNetwork info by @flyth in #2674
  * image based gadgets: return error if no valid gadget layers are
    found by @flyth in #2691
  * resolve symlinks in runtime path by @matthyx in #2656
  * fix: re-add timeout for image-based gadgets by @flyth in #2713
  * ebpf: Remove trailing garbage when reading sample from perf
    event array by @mauriciovasquezbernal in #2720
  * KubeInventoryCache: Keep old pods/svcs in a cached for
    enrichment by @burak-ok in #2659
  * cmd: Require experimental flag for run command. by
    @mauriciovasquezbernal in #2778
  * fix gRPC timeout for image-based gadgets on GetGadgetInfo() by
    @flyth in #2712
  * pkg/oci: Use Singleton for getLocalOciStore by @burak-ok in
    [#2803]
  Documentation Improvements
  * docs/devel: Update hello world gadget guide by @blanquicet in
    [#2668]
  * docs: Document how to verify container image at runtime using
    policy-controller by @eiffel-fl in #2675
  * docs: Fix instructions to verify container image by
    @mauriciovasquezbernal in #2711
  * install-kubernetes.md: Fix and update table of contents by
    @burak-ok in #2749
  * examples: Move gadgets to builtin-gadgets by
    @mauriciovasquezbernal in #2769
  Testing and Continuous Integration
  * release: automatically update artifact hub version by @alban in
    [#2681]
  * integration: Separate and simplify container-related stuff by
    @blanquicet in #2666
  * ci: Add wait to ensure GKE clusters are deleted by
    @mqasimsarfraz in #2682
  * ci/lint: Skip package cache by @burak-ok in #2694
  * Avoid repeated code on inspektor-gadget and kubectl-gadget
    integration tests by @pawarpranav83 in #2450
  * ci: Check that metadata file is updated to
    build-and-push-gadgets by @mauriciovasquezbernal in #2702
  * Testing package for image-based gadgets by @pawarpranav83 in
    [#2607]
  * ci: Always build helper images on main and release branches by
    @mauriciovasquezbernal in #2737
  * integration: Add timestamp to Run/Start/Stop by @burak-ok in
    [#2661]
  * gadgets/trace_open/test: Verify container name and ID by
    @blanquicet in #2759
  * ci: Add workflow to clean eks resources by @burak-ok in #2686
  * test-integration-eks: Fix missing quotes + define explicit
    timeformat by @burak-ok in #2777
  * eks-cleanup: Don't error when stack can't be deleted by
    @burak-ok in #2784
  * TestRunTraceOOMKill: Add sleep after starting ig/kubectl-gadget
    by @burak-ok in #2785
  * integration: Logging timestamp before calling step.Stop by
    @burak-ok in #2790
  * tools: Rewrite check-readme in go by @mauriciovasquezbernal in
    [#2786]
* Thu Apr 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package inspektor-gadget: eBPF tool and systems inspection
  framework for Kubernetes, containers and Linux hosts
